# -*- coding: utf-8 -*-
import sys, re, time
try:
    from urllib2 import urlopen, Request
except ImportError:
    from urllib.request import urlopen, Request
try:
    from urlparse import urlparse, urljoin
except ImportError:
    from urllib.parse import urlparse, urljoin
try:
    from urllib import quote
except ImportError:
    from urllib.parse import quote
if sys.version_info < (2, 7) or (3, 0) <= sys.version_info < (3, 1):
    import simplejson as json
    from simplejson import OrderedDict
else:
    import json
    from collections import OrderedDict
ua = 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/75.0.3770.142 Safari/537.36'


def httpget(url):
    request = Request(url)
    request.add_header('User-Agent', ua)
    return urlopen(request).read().decode('utf-8')


def sports():
    url = 'http://www.huaren.tv/sports'
    try:
        content = httpget(url)
    except Exception as e:
        return {'code': 'huarentv 300', 'error': str(e)}
    content = re.search(r'var\s+pageInfo\s*=\s*(.*?)\s*;', content)
    if not content:
        return {'code': 'huarentv 301'}
    content = content.group(1)
    try:
        data = json.loads(content, object_pairs_hook=OrderedDict)
    except Exception as e:
        return {'code': 'huarentv 302', 'error': str(e)}
    try:
        data = data['live_enter']['0']
    except Exception as e:
        return {'code': 'huarentv 303', 'error': str(e)}
    ret = []
    for e in data:
        title = ''
        if 'time' in e:
            title += time.strftime('%d %H:%M', time.localtime(e['time'])) + ' '
        if 'cate' in e:
            title += e['cate']
        if 'team' in e:
            for e1 in e['team']:
                title += ' ' + e1
        if e['url']:
            ret.append({'title': title, 'url': urljoin(url, e['url'])})
    return ret


def live(url):
    o = urlparse(url)
    p = o.path.split('/')
    ids = p[-1].split('-')
    try:
        content = httpget(url)
    except Exception as e:
        return {'code': 'huarentv 400', 'error': str(e)}
    if len(ids) <= 1:
        content = re.search(r'window.currentPartInfo\s*=\s*(.*?)\s*;', content)
        if not content:
            return {'code': 'huarentv 401'}
        content = content.group(1)
        try:
            data = json.loads(content, object_pairs_hook=OrderedDict)
        except Exception as e:
            return {'code': 'huarentv 402', 'error': str(e)}
        ret = []
        for e1 in data['liveOtherVideo']:
            id1 = e1['tvid']
            for e2 in e1['other_video']:
                id2 = e2['_id']
                ret.append({'title': e2['title'], 'url': '%s-%s' % (url, id2)})
        return ret
    url = re.search(r'changeVideoContent\("m3u8:live","(.*?)"\);', content)
    if not url:
        return {'code': 'huarentv 403'}
    url = url.group(1)
    if url[:2] == '//':
        url = 'http:' + url
    return {'title': '', 'url': url, 'final': True}


def category(cat, page=1):
    if cat == 'movie':
        c = 1
    elif cat == 'tvdrama':
        c = 2
    elif cat == 'show':
        c = 3
    elif cat == 'anime':
        c = 87
    elif cat == 'child':
        c = 101
    elif cat == 'documentary':
        c = 81
    else:
        return {'code': 'huarentv 100'}
    url = 'http://www.wekan.tv/index.php/video?sort=%%7B%%22click15%%22%%3A-1%%7D&where=%%7B%%22channel%%22%%3A%d%%7D&page=%d&pagesize=30' % (
        c, page)
    try:
        content = httpget(url)
    except Exception as e:
        return {'code': 'huarentv 101', 'error': str(e)}
    try:
        data = json.loads(content, object_pairs_hook=OrderedDict)
    except Exception as e:
        return {'code': 'huarentv 102', 'error': str(e)}
    ret = []
    if 'data' not in data:
        return {'code': 'huarentv 103'}
    if 'list' not in data['data']:
        return {'code': 'huarentv 104'}
    for e in data['data']['list']:
        ret.append({'title': e['title'], 'url': urljoin(url, e['url'])})
    ret.append({'title': 'Next Page', 'category': cat, 'page': page + 1})
    return ret


def search(s):
    url = 'https://www.wekan.tv/index.php/search/list?content=%s&page=1&pagesize=20' % quote(s)
    try:
        content = httpget(url)
    except Exception as e:
        return {'code': 'huarentv 500', 'error': str(e)}
    try:
        data = json.loads(content, object_pairs_hook=OrderedDict)
    except Exception as e:
        return {'code': 'huarentv 501', 'error': str(e)}
    ret = []
    for e in data['data']['list']:
        ret.append({'title': e['title'], 'url': urljoin(url, e['url'])})
    return ret


def show(url):
    o = urlparse(url)
    p = o.path.split('/')
    url = 'http://www.wekan.tv/index.php/video/part?tvid=%s' % p[-1]
    try:
        content = httpget(url)
    except Exception as e:
        return {'code': 'huarentv 200', 'error': str(e)}
    try:
        data = json.loads(content, object_pairs_hook=OrderedDict)
    except Exception as e:
        return {'code': 'huarentv 201', 'error': str(e)}
    ret = []
    if 'data' not in data:
        return {'code': 'huarentv 202'}
    if 'partList' not in data['data']:
        return {'code': 'huarentv 203'}
    for e in data['data']['partList']:
        ret.append({'title': e['part_title'], 'url': urljoin(url, e['url'])})
    return ret
